@@ -214,7 +214,7 @@ void Script::print(const char *s, ...) const {
 	putString(buf);
 }
 void Script::printIndent() const {
-	print("%08d:", getPos());
+	print("%08d:", lastOffsetPos());
 	for (uint32 i = 0; i < _indent; i++)
 		putString("	");
 }
@@ -236,7 +236,10 @@ void Script::incIndent() { _indent++; }
 void Script::decIndent() { _indent--; }
 
 uint32 Script::getPos() const { return _ptr - _totData; }
+uint32 Script::lastOffsetPos() const { return _lastOffsetPos - _totData; }
+void Script::updateOffsetPos(uint32 pos) { _lastOffsetPos = _totData + pos; }
 void Script::skip(uint32 off) { seek(off, SEEK_CUR); }
+void Script::skipBlock() {seek(peekUint16(2) + 2, SEEK_CUR);}
 void Script::seek(uint32 off, int whence) {
 	switch (whence) {
 	case SEEK_END:
@@ -371,20 +374,22 @@ std::string Script::readExpr(char stopToken) {
 
 		while ((operation == 14) || (operation == 15)) {
 			if (operation == 14) {
+				// Add a direct offset
 				expr += printStr("#%d#", readUint16() * 4);
 
 				skip(2);
 				if (peekUint8() == 97)
 					skip(1);
 			} else if (operation == 15) {
+				// Add an offset from an array
 				expr += printStr("#%d->", readUint16() * 4);
 
 				skip(2);
-				uint8 var_A = readUint8();
+				dimCount = readUint8();
 
-				skip(var_A);
+				skip(dimCount);
 
-				for (int i = 0; i < var_A; i++)
+				for (int i = 0; i < dimCount; i++)
 					expr += readExpr(12) + "->";
 
 				expr += "#";
@@ -613,7 +618,7 @@ std::string Script::readVarIndex(uint16 *arg_0, uint16 *arg_4) {
 	int16 dim;
 	int16 dimCount;
 	int16 operation;
-	int16 temp;
+	uint16 temp;
 
 	operation = readUint8();
 
@@ -628,7 +633,7 @@ std::string Script::readVarIndex(uint16 *arg_0, uint16 *arg_4) {
 
 			skip(2);
 			if (peekUint8() != 97)
-				return expr;
+				return pref;
 
 			skip(1);
 		} else if (operation == 15) {
@@ -650,7 +655,7 @@ std::string Script::readVarIndex(uint16 *arg_0, uint16 *arg_4) {
 			pref += "#";
 
 			if (peekUint8() != 97)
-				return expr;
+				return pref;
 
 			skip(1);
 		}
@@ -902,7 +907,9 @@ void Script::funcBlock(int16 retFlag) {
 		if (cmd2 == 0)
 			cmd >>= 4;
 
+		updateOffsetPos(getPos());
 		funcOpcode(cmd2, cmd, params);
+		updateOffsetPos(getPos());
 
 	} while (params.counter != params.cmdCount);
 }
@@ -952,6 +959,7 @@ void Script::deGobFunction() {
 			print("--- %s ---\n", it->second.c_str());
 		}
 	}
+	updateOffsetPos(getPos());
 	printIndent();
 	print("sub_%d {\n", getPos());
 	incIndent();
