@@ -68,7 +68,10 @@ public:
 	virtual ~Script();
 
 	uint32 getPos() const;
+	uint32 lastOffsetPos() const;
+	void updateOffsetPos(uint32 pos);
 	void skip(uint32 off);
+	void skipBlock();
 	void seek(uint32 off, int whence = SEEK_SET);
 
 	// Properties getter
@@ -168,7 +171,7 @@ protected:
 	void deGobFunction();
 
 private:
-	byte *_totData, *_ptr;
+	byte *_totData, *_ptr, *_lastOffsetPos;
 	uint32 _totSize;
 
 protected:
@@ -232,6 +235,7 @@ protected:
 
 	// Control functions
 	void o1_callSub(FuncParams &params);
+	void hotspotsEvaluate();
 	void o1_switch(FuncParams &params);
 	void o1_repeatUntil(FuncParams &params);
 	void o1_whileDo(FuncParams &params);
